==> dojo_1.5.0+dfsg.orig.tar.gz: dojo-release-1.5.0-src+dfsg/dijit/_editor/nls/pt/commands.js <==
({
	'bold': 'Negrito',
	'copy': 'Copiar',
	'cut': 'Recortar',
	'delete': 'Excluir',
	'indent': 'Recuar',
	'insertHorizontalRule': 'Régua Horizontal',
	'insertOrderedList': 'Lista Numerada',
	'insertUnorderedList': 'Lista com Marcadores',
	'italic': 'Itálico',
	'justifyCenter': 'Alinhar pelo Centro',
	'justifyFull': 'Justificar',
	'justifyLeft': 'Alinhar pela Esquerda',
	'justifyRight': 'Alinhar pela Direita',
	'outdent': 'Não-chanfrado',
	'paste': 'Colar',
	'redo': 'Refazer',
	'removeFormat': 'Remover Formato',
	'selectAll': 'Selecionar Todos',
	'strikethrough': 'Tachado',
	'subscript': 'Subscrito',
	'superscript': 'Sobrescrito',
	'underline': 'Sublinhado',
	'undo': 'Desfazer',
	'unlink': 'Remover Link',
	'createLink': 'Criar Link',
	'toggleDir': 'Comutar Direção',
	'insertImage': 'Inserir Imagem',
	'insertTable': 'Inserir/Editar Tabela',
	'toggleTableBorder': 'Alternar Moldura da Tabela',
	'deleteTable': 'Excluir Tabela',
	'tableProp': 'Propriedade da Tabela',
	'htmlToggle': 'Origem HTML',
	'foreColor': 'Cor do Primeiro Plano',
	'hiliteColor': 'Cor de segundo plano',
	'plainFormatBlock': 'Estilo de Parágrafo',
	'formatBlock': 'Estilo de Parágrafo',
	'fontSize': 'Tamanho da Fonte',
	'fontName': 'Nome da Fonte',
	'tabIndent': 'Recuo de Guia',
	"fullScreen": "Comutar Tela Cheia",
	"viewSource": "Visualizar Origem HTML",
	"print": "Impressão",
	"newPage": "Nova Página",
	/* Error messages */
	'systemShortcut': 'A ação "${0}" está disponível em seu navegador apenas usando um atalho do teclado. Use ${1}.'
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dijit/_editor/nls/pt/commands.js <==
define(
//begin v1.x content
({
	'bold': 'Negrito',
	'copy': 'Copiar',
	'cut': 'Recortar',
	'delete': 'Excluir',
	'indent': 'Recuar',
	'insertHorizontalRule': 'Régua Horizontal',
	'insertOrderedList': 'Lista Numerada',
	'insertUnorderedList': 'Lista com Marcadores',
	'italic': 'Itálico',
	'justifyCenter': 'Alinhar pelo Centro',
	'justifyFull': 'Justificar',
	'justifyLeft': 'Alinhar à Esquerda',
	'justifyRight': 'Alinhar à Direita',
	'outdent': 'Não chanfrado',
	'paste': 'Colar',
	'redo': 'Refazer',
	'removeFormat': 'Remover Formato',
	'selectAll': 'Selecionar Todos',
	'strikethrough': 'Tachado',
	'subscript': 'Subscrito',
	'superscript': 'Sobrescrito',
	'underline': 'Sublinhado',
	'undo': 'Desfazer',
	'unlink': 'Remover Link',
	'createLink': 'Criar Link',
	'toggleDir': 'Comutar Direção',
	'insertImage': 'Inserir Imagem',
	'insertTable': 'Inserir/Editar Tabela',
	'toggleTableBorder': 'Alternar Moldura da Tabela',
	'deleteTable': 'Excluir Tabela',
	'tableProp': 'Propriedade da Tabela',
	'htmlToggle': 'Origem HTML',
	'foreColor': 'Cor do Primeiro Plano',
	'hiliteColor': 'Cor do Segundo Plano',
	'plainFormatBlock': 'Estilo de Parágrafo',
	'formatBlock': 'Estilo de Parágrafo',
	'fontSize': 'Tamanho da Fonte',
	'fontName': 'Nome da Fonte',
	'tabIndent': 'Recuo de Guia',
	"fullScreen": "Comutar Tela Cheia",
	"viewSource": "Visualizar Origem HTML",
	"print": "Imprimir",
	"newPage": "Nova Página",
	/* Error messages */
	'systemShortcut': 'A ação "${0}" está disponível em seu navegador apenas usando um atalho de teclado. Use ${1}.'
})
//end v1.x content
);
